# Load packages
library(BSDA)
library(ggplot2)
library(fBasics)
library(moments)

#ggplot theme
mytheme <- theme(plot.title=element_text(face="bold.italic",hjust = 0.5,
                                         size = "14", color = "brown"),
                 axis.title=element_text(face="bold.italic", size=10,
                                         color="brown"),
                 axis.text=element_text(face="bold", size=9,
                                        color="darkblue"),
                 panel.background = element_rect(fill="white",
                                                 color="darkblue"),
                 panel.grid.major.y=element_line(color="grey",
                                                 linetype = 2),
                 panel.grid.minor.y=element_line(color="grey",
                                                 linetype=2),
                 panel.grid.minor.x=element_blank(),
                 legend.position = "top")
# Read data
data<-read.table("brca-rsem-fpkm-tcga-t-lab.txt", header = T)

# Extract data of gene KIF1C
gene<-as.numeric(as.matrix(data[1,2:ncol(data)]))

# Use descriptive statistics in R to describe the FPKM of KIF1C gene
# Average
mean(gene)
#Range
range(gene)
# Standard deviation
sd(gene)
# Median
median(gene)
# Define function to calculate mode
Mode = function(x) {
  as.numeric(names(table(x))[table(x)==max(table(x))])
}
# Mode and its frequency
Mode(gene)
max(table(gene))
# Sum
sum(gene)
# Summary
summary(gene)
# Kurtosis and Skewness
kurtosis(gene)
skewness(gene)

# Histogram with density line
temp <- data.frame(gene)
ggplot(temp, aes(gene, ..density..)) +
  geom_histogram(bins = 30, fill = "lightblue", colour = "black") +
  geom_density(alpha = 0.3, fill = "lightgreen") +
  theme_bw() +
  theme(legend.position="none", 
        axis.text.x=element_text(colour="black",size=14), 
        axis.text.y=element_text(size=14,face="plain"), 
        axis.title.y=element_text(size = 14,face="plain"),
        axis.title.x=element_text(size = 14,face="plain"), 
        plot.title = element_text(size=15,face="bold",hjust = 0.5)) +
  ylab("Density") +
  xlab("FPKM") +
  ggtitle("Histogram for the FPKM of KIF1C")

# Get sample size of 200
sp=sample(gene,200,replace=F)
mean(sp)
spMean<-c(1:1000)
spPValue<-c(1:10000)
for(i in 1:1000){
  spMean[i]<-mean(sample(gene,200,replace=F))
}
# one sample z.test()
for(i in 1:10000){
  sp=sample(gene,200,replace=F)
  zt<-z.test(sp,alternative = "two.sided", 
             mu = mean(gene), 
             sigma.x = sd(gene), 
             conf.level = 0.95)
  spPValue[i]<-zt$p.value
}

#boxplot
sample1<-sample(gene,200,replace = F)
sample2<-sample(gene,200,replace = F)
sample3<-sample(gene,200,replace = F)
temp<-as.data.frame(cbind(group=c(rep("first",200),rep("second",200),rep("third",200)),sample=c(sample1,sample2,sample3)))
temp <- data.frame("group"=temp$group,"sample"=as.numeric(as.character(temp$sample)))
plot_boxplot <- ggplot(temp, aes(y =sample,fill = group))
plot_boxplot + 
  geom_boxplot() +
  geom_hline(yintercept = mean(gene), linetype="dashed", color = "black", size=0.5) +
  mytheme+
  labs(
    title="Boxplot for the three times of sampling",y="FPKM"
  )+ylim(0,3000)

#point plot
temp2<-data.frame(group=c("first sampling","second sampling","third sampling"),pvalue=rep(z.test(sample(gene,200,replace=F),alternative = "two.sided", 
                                                   mu = mean(gene), 
                                                   sigma.x = sd(gene), 
                                                   conf.level = 0.95)$p.value,3))
temp2$pvalue[2]=z.test(sample(gene,200,replace=F),alternative = "two.sided", 
          mu = mean(gene), 
          sigma.x = sd(gene), 
          conf.level = 0.95)$p.value
temp2$pvalue[3]=z.test(sample(gene,200,replace=F),alternative = "two.sided", 
                       mu = mean(gene), 
                       sigma.x = sd(gene), 
                       conf.level = 0.95)$p.value
ggplot(temp2, aes(x=group, y=pvalue,color = group,shape =group)) + 
  geom_point(size = 8) +
  geom_hline(yintercept = 0.05, linetype="dashed", color = "red", size=2) +
  mytheme+
  ylab("p-Value") +
  labs(
    title="Plot for the three times of z-test"
  )



#another plot
temp<-rbind(data.frame(source='RawData',value=gene),data.frame(source='Samples',value=spMean))
temp[,1]<-as.factor(temp[,1])


ggplot(data = temp,aes(x=value,color=source,fill=source)) +
  geom_density(alpha = 0.3) +
  theme_bw() +
mytheme+
  ylab("Density") +
  xlab("FPKM") +
  labs(
    title="Density Plot for the raw data and sample means",
    subtitle="Sampling process was repeated 1000x. "
  ) +
  scale_color_manual(values = c('RawData' = 'red', 'Samples' = 'blue'))

ggplot(data=as.data.frame(spPValue),aes(x=spPValue)) +
  geom_density(alpha = 0.3,fill = "lightblue") +
  theme_bw() +
 mytheme+
  ylab("Density") +
  xlab("p_Value") +
  labs(
    title="Density Plot for the p-value of z-test",
    subtitle="Sampling process was repeated 10000x. "
  )
